Exactly one of uri, file or string must be given. Validation is then performed by using the W3C Markup Validation
service at the given URL, using the (still declared
experimental) SOAP 1.2 API of such a service (see
http://validator.w3.org/docs/api.html for more information).
If a SOAP validation response could be obtained,
w3c_markup_validate() returns the information in the response
organized into an object of class "w3c_markup_validate", which
is a list with the following elements:
[object Object],[object Object],[object Object],[object Object],[object Object]
This class has methods for print for compactly
summarizing the results, an inspect method for inspecting
details, and an as.data.frame method for collapsing the
errors and warnings into a flat data frame useful for further
analyses.